#################
Parameter classes
#################

The parameter classes are used to define input variables for a :class:`.Procedure`. They each inherit from the :class:`.Parameter` base class.

.. automodule:: pymeasure.experiment.parameters
    :members: